pub enum ExtractError {
IoError(Error),
HashMismatch {
url: String,
destination: String,
expected: String,
actual: String,
total_size: u64,
},
CouldNotCreateDestination(Error),
ZipError(ZipError),
AsyncZipError(ZipError),
MissingComponent,
UnsupportedCompressionMethod,
ReqwestError(Error),
AsyncHttpRangeReaderError(AsyncHttpRangeReaderError),
UnsupportedArchiveType,
Cancelled,
ArchiveMemberParseError(PathBuf, Error),
}Expand description
An error that can occur when extracting a package archive.
Variants
IoError(Error)
HashMismatch
CouldNotCreateDestination(Error)
ZipError(ZipError)
AsyncZipError(ZipError)
MissingComponent
UnsupportedCompressionMethod
ReqwestError(Error)
AsyncHttpRangeReaderError(AsyncHttpRangeReaderError)
UnsupportedArchiveType
Cancelled
ArchiveMemberParseError(PathBuf, Error)
Implementations
Sourceimpl ExtractError
impl ExtractError
Sourcepub fn should_retry(&self) -> bool
pub fn should_retry(&self) -> bool
Returns true if this error is transient and the operation should be retried.
This checks for common transient I/O errors like broken pipes, connection resets, and unexpected EOF that can occur during network streaming operations.